<?php

namespace App\Http\Controllers;

use App\Category;
use App\ContactForm;
use App\InquiryProduct;
use App\Prodcut;
use App\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Validator;

class Admin extends Controller
{

    public function __construct()
    {
        $this->middleware(['auth', 'verified']);
    }

    /** Created at:- 08-04-2019
     * Created by:- Sanjaya Prasanna
     * Summery:- Load data to admin dashboard index view
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function index()
    {
        if (Auth::user()->role > 0){
            $title = "Dashboard";
            $products = Prodcut::all()->count();
            $categories = Category::all()->count();
            $leads = ContactForm::all()->count();
            return view('admin.dashboard', compact('title', 'products', 'categories', 'leads'));
        } else {
            redirect('/login')->with('status', 'You do not have permission for access this page');
        }

    }

    /** Created at:- 08-04-2019
     * Created by:- Sanjaya Prasanna
     * Summery:- Register new admin user for backend
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function staffRegister()
    {

        if (Auth::user()->role == 3){
            $title = "User Register";
            $data = User::all();
            return view('admin.userRegister', compact('title' , 'data'));
        } else {
            redirect('/login')->with('status', 'You do not have permission for access this page');
        }
    }

    public function staffStore(Request $request)
    {

        $validator = Validator::make($request->all(), [
            'name' => ['required', 'string', 'max:255', 'unique:users'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:6', 'confirmed'],
        ],
            [
                'name.required' => 'Name field is required',
                'name.unique' => 'This name already exists. Please use another name',
                'email.unique' => 'This email already exists',
                'email.required' => 'Category field is required',
                'password.required' => 'Password field is required',
                'password.confirmed' => 'Password does not match with confirm password field',
            ]
        );
        if ($validator->fails()) {
            return redirect('admin/register')
                ->withErrors($validator)
                ->withInput();
        }
            User::create([
            'name' => $request['name'],
            'email' => $request['email'],
            'password' => Hash::make($request['password']),
        ]);

        return back()->with('status', 'User Successfully created');
    }

    public function liveChat()
    {
        if (Auth::user()->role == 3){
            $title = "Live Chat";
            return view('admin.liveChat', compact('title'));
        } else {
            redirect('/login')->with('status', 'You do not have permission for access this page');
        }
    }
}
