<?php

namespace App\Http\Controllers;

use App\Category;
use App\Prodcut;
use App\Product_gallery;
use Illuminate\Http\Request;
use Validator;
use Image;
use Auth;
use File;

class Product extends Controller
{
    public function __construct(){

    }

    /** Created by: Sanjaya Prasanna
     * Summery: Load existing products and insert form for products
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function index()
    {
        if (Auth::user()->role > 0){
            $data = Prodcut::where('status', '0')->get();
            $title = "Manage Products";
            $categories = Category::all();
            return view('admin.product.manage', compact('data', 'title', 'categories'));
        } else {
            redirect('/login')->with('status', 'You do not have permission for access this page');
        }
    }

    /**
     * Created by: Sanjaya Prasanna
     * Summery: Insert products data to database and upload images to directories
     * @param Request $request
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function store(Request $request)
    {
      //  dd($request->all());
        $validator = Validator::make($request->all(), [
            'name' => 'required|max:100|unique:products',
            'category_id' => 'required',
            'description' => 'required',
            'feature_image' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:1024',
            'thumbnail' => 'required|image|mimes:jpeg,png,jpg,gif,svg|max:1024',
            'status' => 'required',
        ],
            [
                'name.required' => 'Product Name field is required',
                'name.unique' => 'This Product name is already exists',
                'category_id.required' => 'Category field is required',
                'description.required' => 'Description field is required',
                'status.required' => 'Status field is required',
            ]
        );
        if ($validator->fails()) {
            return redirect('admin/product')
                ->withErrors($validator)
                ->withInput();
        }
        $image= $request->file('feature_image');
        $image_path = Image::make($image);
        $set_img_path = time().$image->getClientOriginalName();
        $image_path->save( public_path().'/uploads/products/'.$set_img_path);

        $image2= $request->file('thumbnail');
        $image_path = Image::make($image2);
        $set_img_path2 = time().$image2->getClientOriginalName();
        $path = public_path('/uploads/products/thumbnail/' .  $set_img_path2);
        Image::make($image2->getRealPath())->resize(350, 250)->save($path);

        $title = strtolower($request->name);
        Prodcut::create([
            'name' => $request->name,
            'cat_id' => $request->category_id,
            'description' => $request->description,
            'slug' => str_slug($title, '-'),
            'user_id' => Auth::user()->id,
            'feature_image' => $set_img_path,
            'status' => $request->status,
            'offer' => $request->offer,
            'thumbnail' => $set_img_path2,
            'selling_price' => $request->selling_price,
            'offer_price' => $request->offer_price,
        ]);
        return back()->with('status', 'Product Successfully created');
    }

    /**Created by: Sanjaya Prasanna
     * Summery: Edit view for update existing products data
     * @param $id
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function edit($id)
    {
        if (Auth::user()->role > 0){
            $title = "Edit Product";
            $data = Prodcut::find($id);
            $categories = Category::all();
            return view('admin.product.edit', compact('data', 'title', 'categories'));
        } else {
            redirect('/login')->with('status', 'You do not have permission for access this page');
        }
    }

    /**Created by: Sanjaya Prasanna
     * Summery: Update existing products data
     * @param Request $request
     * @param $id
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function update(Request $request, $id){

        $validator = Validator::make($request->all(), [
            'name' => 'required|max:100',
            'category_id' => 'required',
            'description' => 'required',
            'status' => 'required'
        ],
            [
                'name.required' => 'Product Name field is required',
                'category_id.required' => 'Category field is required',
                'description.required' => 'Description field is required',
                'status.required' => 'Status field is required',
            ]
        );
        if ($validator->fails()) {
            return redirect('admin/product/edit/'.$id)
                ->withErrors($validator)
                ->withInput();
        }
        $data = Prodcut::find($id);
        $data["name"] = $request->name;
        $data["cat_id"] = $request->category_id;
        $data["description"] = $request->description;
        $data["status"] = $request->status;
        $data["offer"] = $request->offer;
        $data["selling_price"] = $request->selling_price;
        $data["offer_price"] = $request->offer_price;
        $data->save();
        return back()->with('status', 'Product Successfully updated');

    }

    /**Created by: Sanjaya Prasanna
     * Summery: Update existing product feature image and delete old image file from relevant directory
     * @param Request $request
     * @param $id
     * @return \Illuminate\Http\RedirectResponse
     */
    public function image_update(Request $request, $id){

        //dd($request->all());
        $image= $request->file('feature_image');
        $image_path = Image::make($image);
        $set_img_path = time().$image->getClientOriginalName();
        $image_path->save( public_path().'/uploads/products/'.$set_img_path);

        File::delete('uploads/products/'.$request->current_feature_image);

        $data = Prodcut::find($id);
        $data["feature_image"] = $set_img_path;
        $data->save();
        return back()->with('status', 'Product feature image updated');

    }

    /**Created by: Sanjaya Prasanna
     * Summery: Update existing product thumbnail image and delete old image file from relevant directory
     * @param Request $request
     * @param $id
     * @return \Illuminate\Http\RedirectResponse
     */
    public function feature_image_update(Request $request, $id){

        $image2= $request->file('thumbnail');
        $image_path = Image::make($image2);
        $set_img_path2 = time().$image2->getClientOriginalName();
        $path = public_path('/uploads/products/thumbnail/' .  $set_img_path2);
        Image::make($image2->getRealPath())->resize(350, 250)->save($path);

        File::delete('uploads/products/thumbnail/'.$request->current_thumbnail);

        $data = Prodcut::find($id);
        $data["thumbnail"] =  $set_img_path2;
        $data->save();
        return back()->with('status', 'Product thumbnail image updated');

    }

    /**Created by: Sanjaya Prasanna
     * Summery: Product gallery image insert view
     * @param $id
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function gallery($id){


        if (Auth::user()->role > 0){
            $title = "Product Gallery";
            $product = Prodcut::all('id')->find($id);
            $data = Product_gallery::all()->where('product_id',$id);
            return view('admin.product.manage_gallery', compact('data', 'title', 'product'));
        } else {
            redirect('/login')->with('status', 'You do not have permission for access this page');
        }

    }

    /**Created by: Sanjaya Prasanna
     * Summery: Insert product gallery images to image directory
     *          and insert file name to database with product id
     * @param $id
     * @return \Illuminate\Contracts\View\Factory|\Illuminate\View\View
     */
    public function gallery_store(Request $request){

        $id = $request['id'];

        $imageName = request()->file->getClientOriginalName();
        $img_path = time().$imageName;
        request()->file->move(public_path('/uploads/products/gallery/'), $img_path);

        $data = new Product_gallery;
        $data["file"] = $img_path;
        $data["product_id"] = $id;
         $data["user_id"] = Auth::user()->id;
        $data->save();

        return response()->json(['success' => '/uploads/products/gallery/'.$imageName]);
    }

    /**Created by: Sanjaya Prasanna
     * Summery: Delete product gallery image from database and upload directory.
     * @param Request $request
     * @param $id
     * @return \Illuminate\Http\RedirectResponse|\Illuminate\Routing\Redirector
     */
    public function gallery_destroy(Request $request, $id){

        $data = Product_gallery::findOrFail($id);
        File::delete('uploads/products/gallery/'.$data->file);
        $data->delete();
        return redirect('admin/product/')->with('status', 'Gallery image successfully deleted');

    }

}
